//[mahjong-utils](../../../index.md)/[mahjongutils.hora](../index.md)/[HoraOptions](index.md)/[hanHuOptions](han-hu-options.md)

# hanHuOptions

[common]\
val [hanHuOptions](han-hu-options.md): [HanHuOptions](../../mahjongutils.hanhu/-han-hu-options/index.md)
